@@ -4,9 +4,9 @@ tcpyPI: Tropical Cyclone Potential Intensity Calculations in Python
 tcpyPI, 'pyPI' for short, is a set of functions, scripts, and notebooks that compute and validate tropical cyclone potential intensity (PI) calculations in Python. It is a port of the Bister and Emanuel (2002) algorithm (Bister and Emanuel 2002) which was originally written in FORTRAN---and then converted to MATLAB---by Prof. Kerry Emanuel (MIT).
 """
 
-__author__ = "Daniel M. Gilford <daniel.gilford@rutgers.edu>"
+__author__ = "Daniel M. Gilford <dgilford@climatecentral.org>"
 
 # TODO: Re-factor module-wide implicit imports
 from .pi import *
 from .constants import *
-from .utilities import *
\ No newline at end of file
+from .utilities import *
